import { ConnectLogger } from "../logging";
import { ConnectMetricRecorder, } from "../metric";
import { getGlobalProvider } from "../provider";
import { ModuleContext } from "./module-context";
export class Context {
    constructor(provider) {
        this.provider = provider;
    }
    getProxy() {
        return this.getProvider().getProxy();
    }
    getModuleContext(moduleNamespace) {
        return new ModuleContext(this, moduleNamespace);
    }
    getProvider() {
        if (this.provider)
            return this.provider;
        else
            return getGlobalProvider();
    }
    createLogger(params) {
        if (typeof params === "object") {
            return new ConnectLogger(Object.assign(Object.assign({}, params), { provider: () => this.getProvider() }));
        }
        else {
            return new ConnectLogger({
                source: params,
                provider: () => this.getProvider(),
            });
        }
    }
    createMetricRecorder(params) {
        if (typeof params === "object") {
            return new ConnectMetricRecorder(Object.assign(Object.assign({}, params), { provider: () => this.getProvider() }));
        }
        else {
            return new ConnectMetricRecorder({
                namespace: params,
                provider: () => this.getProvider(),
            });
        }
    }
}
//# sourceMappingURL=context.js.map