"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Context = void 0;
const logging_1 = require("../logging");
const metric_1 = require("../metric");
const provider_1 = require("../provider");
const module_context_1 = require("./module-context");
class Context {
    constructor(provider) {
        this.provider = provider;
    }
    getProxy() {
        return this.getProvider().getProxy();
    }
    getModuleContext(moduleNamespace) {
        return new module_context_1.ModuleContext(this, moduleNamespace);
    }
    getProvider() {
        if (this.provider)
            return this.provider;
        else
            return (0, provider_1.getGlobalProvider)();
    }
    createLogger(params) {
        if (typeof params === "object") {
            return new logging_1.ConnectLogger(Object.assign(Object.assign({}, params), { provider: () => this.getProvider() }));
        }
        else {
            return new logging_1.ConnectLogger({
                source: params,
                provider: () => this.getProvider(),
            });
        }
    }
    createMetricRecorder(params) {
        if (typeof params === "object") {
            return new metric_1.ConnectMetricRecorder(Object.assign(Object.assign({}, params), { provider: () => this.getProvider() }));
        }
        else {
            return new metric_1.ConnectMetricRecorder({
                namespace: params,
                provider: () => this.getProvider(),
            });
        }
    }
}
exports.Context = Context;
//# sourceMappingURL=context.js.map