import { AmazonConnectConfig } from "../amazon-connect-config";
import { AmazonConnectError, AmazonConnectErrorHandler } from "../amazon-connect-error";
import { AmazonConnectNamespace } from "../amazon-connect-namespace";
import { LogProxy, ProxyLogData } from "../logging";
import { AcknowledgeMessage, ChildConnectionEnabledDownstreamMessage, ChildConnectionEnabledUpstreamMessage, LogMessage, MetricMessage, UpstreamMessageOrigin } from "../messaging";
import { SubscriptionHandler, SubscriptionHandlerData, SubscriptionTopic } from "../messaging/subscription";
import { MetricProxy, ProxyMetricData } from "../metric";
import { AmazonConnectProvider } from "../provider";
import { ConnectRequestData, ConnectResponseData } from "../request";
import { AddChannelParams, UpdateChannelPortParams } from "./channel-manager";
import { HealthCheckStatusChangedHandler } from "./health-check";
import { ProxyConnectionChangedHandler, ProxyConnectionStatus, ProxyConnectionStatusManager } from "./proxy-connection";
export declare abstract class Proxy<TConfig extends AmazonConnectConfig = AmazonConnectConfig, TUpstreamMessage extends {
    type: string;
} | ChildConnectionEnabledUpstreamMessage = ChildConnectionEnabledUpstreamMessage, TDownstreamMessage extends {
    type: string;
} | ChildConnectionEnabledDownstreamMessage = ChildConnectionEnabledDownstreamMessage> implements LogProxy, MetricProxy {
    protected readonly provider: AmazonConnectProvider<TConfig>;
    protected readonly status: ProxyConnectionStatusManager;
    private readonly subscriptions;
    private readonly errorService;
    private readonly logger;
    private readonly channelManager;
    private readonly healthCheck;
    private requestManager;
    private upstreamMessageQueue;
    private connectionEstablished;
    private isInitialized;
    private connectionId;
    constructor(provider: AmazonConnectProvider<TConfig>);
    init(): void;
    protected abstract initProxy(): void;
    request<TResponse extends ConnectResponseData>(namespace: AmazonConnectNamespace, command: string, data?: ConnectRequestData, origin?: UpstreamMessageOrigin): Promise<TResponse>;
    subscribe<THandlerData extends SubscriptionHandlerData>(topic: SubscriptionTopic, handler: SubscriptionHandler<THandlerData>, origin?: UpstreamMessageOrigin): void;
    unsubscribe<THandlerData extends SubscriptionHandlerData>(topic: SubscriptionTopic, handler: SubscriptionHandler<THandlerData>, origin?: UpstreamMessageOrigin): void;
    log(logData: ProxyLogData): void;
    sendLogMessage(message: LogMessage): void;
    sendMetric({ metricData, time, namespace }: ProxyMetricData): void;
    sendMetricMessage(metricMessage: MetricMessage): void;
    protected sendOrQueueMessageToSubject(message: TUpstreamMessage): void;
    protected abstract sendMessageToSubject(message: TUpstreamMessage): void;
    protected abstract addContextToLogger(): Record<string, unknown>;
    protected abstract getUpstreamMessageOrigin(): UpstreamMessageOrigin;
    protected consumerMessageHandler(evt: MessageEvent<any>): void;
    protected handleMessageFromSubject(msg: TDownstreamMessage): void;
    private handleDefaultMessageFromSubject;
    protected handleConnectionAcknowledge(msg: AcknowledgeMessage): void;
    private handleResponse;
    private handlePublish;
    private handleError;
    protected publishError(error: Omit<AmazonConnectError, "connectionStatus">): void;
    private handleAsyncSubscriptionHandlerInvoke;
    abstract get proxyType(): string;
    get connectionStatus(): ProxyConnectionStatus;
    onError(handler: AmazonConnectErrorHandler): void;
    offError(handler: AmazonConnectErrorHandler): void;
    onConnectionStatusChange(handler: ProxyConnectionChangedHandler): void;
    offConnectionStatusChange(handler: ProxyConnectionChangedHandler): void;
    onHealthCheckStatusChanged(handler: HealthCheckStatusChangedHandler): void;
    offHealthCheckStatusChanged(handler: HealthCheckStatusChangedHandler): void;
    addChildChannel(params: AddChannelParams): void;
    updateChildChannelPort(params: UpdateChannelPortParams): void;
    protected resetConnection(reason: string): void;
}
//# sourceMappingURL=proxy.d.ts.map